<?php
/**
 * Halloween Party Theme Customizer
 *
 * @package Halloween Party
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function halloween_party_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'halloween_party_custom_controls' );

function halloween_party_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'halloween_party_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'halloween_party_Customize_partial_blogdescription',
	));

	//Homepage Settings
	$wp_customize->add_panel( 'halloween_party_homepage_panel', array(
		'title' => esc_html__( 'Homepage Settings', 'halloween-party' ),
		'panel' => 'halloween_party_panel_id',
		'priority' => 20,
	));

	//Topbar
	$wp_customize->add_section( 'halloween_party_topbar_section' , array(
    	'title' => __( 'Topbar Section', 'halloween-party' ),
		'panel' => 'halloween_party_homepage_panel'
	) );

	$wp_customize->add_setting( 'halloween_party_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'halloween_party_switch_sanitization'
    ));  
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','halloween-party' ),
      'section' => 'halloween_party_topbar_section'
    )));

	$wp_customize->add_setting('halloween_party_timing_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_timing_text',array(
		'label'	=> esc_html__('Add Timing','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Opening Hours: 7PM to 2PM-October 31st 2022', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('halloween_party_topbar_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_topbar_text',array(
		'label'	=> esc_html__('Add Topbar Text','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'After Dark Halloween Party!', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('halloween_party_topbar_facebook_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('halloween_party_topbar_facebook_link',array(
		'label'	=> esc_html__('Add Facebook Link','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.facebook.com', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_topbar_section',
		'type'=> 'url'
	));

	$wp_customize->add_setting('halloween_party_topbar_twitter_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('halloween_party_topbar_twitter_link',array(
		'label'	=> esc_html__('Add Twitter Link','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.twitter.com', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_topbar_section',
		'type'=> 'url'
	));

	$wp_customize->add_setting('halloween_party_topbar_instagram_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('halloween_party_topbar_instagram_link',array(
		'label'	=> esc_html__('Add Instagram Link','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.instagram.com', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_topbar_section',
		'type'=> 'url'
	));

	$wp_customize->add_setting('halloween_party_topbar_pinterest_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('halloween_party_topbar_pinterest_link',array(
		'label'	=> esc_html__('Add Pinterest Link','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.pinterest.com', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_topbar_section',
		'type'=> 'url'
	));

	//Header
	$wp_customize->add_section( 'halloween_party_header_settings' , array(
    	'title'      => __( 'Header', 'halloween-party' ),
		'panel' => 'halloween_party_homepage_panel'
	) );

	$wp_customize->add_setting('halloween_party_tickets_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_tickets_btn_text',array(
		'label'	=> esc_html__('Add Button Text','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'GET PARTY TICKETS', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_header_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('halloween_party_tickets_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('halloween_party_tickets_btn_link',array(
		'label'	=> esc_html__('Add Button Link','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example.com', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_header_settings',
		'type'=> 'url'
	));

	$wp_customize->add_setting('halloween_party_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_header_menus_color', array(
		'label'    => __('Menus Color', 'halloween-party'),
		'section'  => 'halloween_party_header_settings',
	)));

	$wp_customize->add_setting('halloween_party_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'halloween-party'),
		'section'  => 'halloween_party_header_settings',
	)));

	$wp_customize->add_setting('halloween_party_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'halloween-party'),
		'section'  => 'halloween_party_header_settings',
	)));

	$wp_customize->add_setting('halloween_party_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'halloween-party'),
		'section'  => 'halloween_party_header_settings',
	)));

	//Slider
	$wp_customize->add_section( 'halloween_party_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'halloween-party' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/halloween-party-wordpress-theme/">GO PRO</a>','halloween-party'),
		'panel' => 'halloween_party_homepage_panel'
	) );

	$wp_customize->add_setting( 'halloween_party_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'halloween_party_switch_sanitization'
    ));  
  $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','halloween-party' ),
      'section' => 'halloween_party_slidersettings'
    )));

  $wp_customize->add_setting('halloween_party_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	) );
	$wp_customize->add_control('halloween_party_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','halloween-party'),
        'section' => 'halloween_party_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','halloween-party'),
            'Advance slider' => __('Advance slider','halloween-party'),
        ),
	));

	$wp_customize->add_setting('halloween_party_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','halloween-party'),
		'section'=> 'halloween_party_slidersettings',
		'type'=> 'text',
		'active_callback' => 'halloween_party_advance_slider'
	));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('halloween_party_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'halloween_party_customize_partial_halloween_party_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'halloween_party_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'halloween_party_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'halloween_party_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'halloween-party' ),
			'description' => __('Slider image size (1400 x 550)','halloween-party'),
			'section'  => 'halloween_party_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'halloween_party_default_slider'
		) );
	}

	$wp_customize->add_setting( 'halloween_party_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'halloween_party_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','halloween-party'),
		'section' => 'halloween_party_slidersettings',
		'type'  => 'text',
		'active_callback' => 'halloween_party_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('halloween_party_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_slider_height',array(
		'label'	=> __('Slider Height','halloween-party'),
		'description'	=> __('Specify the slider height (px).','halloween-party'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_slidersettings',
		'type'=> 'text',
		'active_callback' => 'halloween_party_default_slider'
	));

	//About Section
	$wp_customize->add_section('halloween_party_about', array(
		'title'       => __('About Us Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_about_text',array(
		'description' => __('<p>1. More options for about us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about us section.</p>','halloween-party'),
		'section'=> 'halloween_party_about',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_about',
		'type'=> 'hidden'
	));

	//Party Host Section
	$wp_customize->add_section('halloween_party_party_host', array(
		'title'       => __('Party Host Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_party_host_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_party_host_text',array(
		'description' => __('<p>1. More options for Party Host section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Party Host section.</p>','halloween-party'),
		'section'=> 'halloween_party_party_host',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_party_host_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_party_host_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_party_host',
		'type'=> 'hidden'
	));

	//Promotion Section
	$wp_customize->add_section('halloween_party_promotion', array(
		'title'       => __('Promotion Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_promotion_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_promotion_text',array(
		'description' => __('<p>1. More options for Promotion section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Promotion section.</p>','halloween-party'),
		'section'=> 'halloween_party_promotion',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_promotion_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_promotion_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_promotion',
		'type'=> 'hidden'
	));

	//Gallery Section
	$wp_customize->add_section('halloween_party_hallo_gallery', array(
		'title'       => __('Gallery Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_hallo_gallery_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_hallo_gallery_text',array(
		'description' => __('<p>1. More options for Gallery section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Gallery section.</p>','halloween-party'),
		'section'=> 'halloween_party_hallo_gallery',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_hallo_gallery_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_hallo_gallery_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_hallo_gallery',
		'type'=> 'hidden'
	));

	// Event Series Section
	$wp_customize->add_section('halloween_party_events_section',array(
		'title'	=> __('Events Section','halloween-party'),
		'description' => __('For more options of event section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/halloween-party-wordpress-theme/">GO PRO</a>','halloween-party'),
		'panel' => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting( 'halloween_party_events_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'halloween_party_events_small_title', array(
		'label'    => __( 'Add Section Small Title', 'halloween-party' ),
		'input_attrs' => array(
            'placeholder' => __( 'Party Hosts', 'halloween-party' ),
        ),
		'section'  => 'halloween_party_events_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'halloween_party_events_heading', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'halloween_party_events_heading', array(
		'label'    => __( 'Add Section Heading', 'halloween-party' ),
		'input_attrs' => array(
            'placeholder' => __( 'Our Events for the Party', 'halloween-party' ),
        ),
		'section'  => 'halloween_party_events_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'halloween_party_noof_events_tab', array(
		'default'           => '3',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'halloween_party_noof_events_tab', array(
		'label'    => __( 'No. of Events Tabs', 'halloween-party' ),
		'section'  => 'halloween_party_events_section',
		'type'     => 'number'
	) );

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$pst[]='Select';  
	foreach($post_list as $post){
		$pst[$post->post_title] = $post->post_title;
	}

	for ( $count = 1; $count < 4; $count++ ) {

		$wp_customize->add_setting( 'halloween_party_tab_pages' . $count, array(
			'sanitize_callback' => 'halloween_party_sanitize_choices'
		));
		$wp_customize->add_control( 'halloween_party_tab_pages' . $count, array(
			'label'    => __( 'Select Post', 'halloween-party' ),
			'section'  => 'halloween_party_events_section',
			'type'    => 'select',
			'choices' => $pst,
		));
	}

	//Entry Passes Section
	$wp_customize->add_section('halloween_party_entry_passes', array(
		'title'       => __('Entry Passes Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_entry_passes_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_entry_passes_text',array(
		'description' => __('<p>1. More options for Entry Passes section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Entry Passes section.</p>','halloween-party'),
		'section'=> 'halloween_party_entry_passes',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_entry_passes_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_entry_passes_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_entry_passes',
		'type'=> 'hidden'
	));

	//Testimonial Section
	$wp_customize->add_section('halloween_party_testimonial', array(
		'title'       => __('Testimonial Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_testimonial_text',array(
		'description' => __('<p>1. More options for Testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Testimonial section.</p>','halloween-party'),
		'section'=> 'halloween_party_testimonial',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_testimonial',
		'type'=> 'hidden'
	));

	//Instagram Section
	$wp_customize->add_section('halloween_party_instagram', array(
		'title'       => __('Instagram Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_instagram_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_instagram_text',array(
		'description' => __('<p>1. More options for Instagram section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Instagram section.</p>','halloween-party'),
		'section'=> 'halloween_party_instagram',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_instagram_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_instagram_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_instagram',
		'type'=> 'hidden'
	));

	//Newsletter Section
	$wp_customize->add_section('halloween_party_newsletter', array(
		'title'       => __('Newsletter Section', 'halloween-party'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','halloween-party'),
		'priority'    => null,
		'panel'       => 'halloween_party_homepage_panel',
	));

	$wp_customize->add_setting('halloween_party_newsletter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_newsletter_text',array(
		'description' => __('<p>1. More options for Newsletter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Newsletter section.</p>','halloween-party'),
		'section'=> 'halloween_party_newsletter',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('halloween_party_newsletter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_newsletter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=halloween_party_guide') ." '>More Info</a>",
		'section'=> 'halloween_party_newsletter',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('halloween_party_footer',array(
		'title'	=> esc_html__('Footer Settings','halloween-party'),
		'description' => __('For more options of footer section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/halloween-party-wordpress-theme/">GO PRO</a>','halloween-party'),
		'panel' => 'halloween_party_homepage_panel',
	));	

	$wp_customize->add_setting('halloween_party_footer_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_footer_background_color', array(
		'label'    => __('Footer Background Color', 'halloween-party'),
		'section'  => 'halloween_party_footer',
	)));

	$wp_customize->add_setting('halloween_party_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'halloween_party_footer_background_image',array(
        'label' => __('Footer Background Image','halloween-party'),
        'section' => 'halloween_party_footer'
	)));

	$wp_customize->add_setting('halloween_party_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','halloween-party'),
        'section' => 'halloween_party_footer',
        'choices' => array(
        	'Left' => __('Left','halloween-party'),
            'Center' => __('Center','halloween-party'),
            'Right' => __('Right','halloween-party')
        ),
	) );

	$wp_customize->add_setting('halloween_party_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','halloween-party'),
        'section' => 'halloween_party_footer',
        'choices' => array(
        	'Left' => __('Left','halloween-party'),
            'Center' => __('Center','halloween-party'),
            'Right' => __('Right','halloween-party')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('halloween_party_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','halloween-party'),
		'description'	=> __('Enter a value in pixels. Example:20px','halloween-party'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'halloween-party' ),
    ),
		'section'=> 'halloween_party_footer',
		'type'=> 'text'
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('halloween_party_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'halloween_party_Customize_partial_halloween_party_footer_text', 
	));
	
	$wp_customize->add_setting('halloween_party_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('halloween_party_footer_text',array(
		'label'	=> esc_html__('Copyright Text','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('halloween_party_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control(new Halloween_Party_Image_Radio_Control($wp_customize, 'halloween_party_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','halloween-party'),
        'section' => 'halloween_party_footer',
        'settings' => 'halloween_party_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

	// footer social icon
	$wp_customize->add_setting( 'halloween_party_footer_icon',array(
	'default' => false,
	'transport' => 'refresh',
	'sanitize_callback' => 'halloween_party_switch_sanitization'
  ) );
	$wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_footer_icon',array(
	'label' => esc_html__( 'Footer Social Icon','halloween-party' ),
	'section' => 'halloween_party_footer'
  )));

  $wp_customize->add_setting( 'halloween_party_hide_show_scroll',array(
  	'default' => 1,
    	'transport' => 'refresh',
    	'sanitize_callback' => 'halloween_party_switch_sanitization'
  ));  
  $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_hide_show_scroll',array(
    	'label' => esc_html__( 'Show / Hide Scroll to Top','halloween-party' ),
    	'section' => 'halloween_party_footer'
  )));

   //Selective Refresh
	$wp_customize->selective_refresh->add_partial('halloween_party_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'halloween_party_Customize_partial_halloween_party_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('halloween_party_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control(new Halloween_Party_Image_Radio_Control($wp_customize, 'halloween_party_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','halloween-party'),
        'section' => 'halloween_party_footer',
        'settings' => 'halloween_party_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	//Blog Post Settings
	$wp_customize->add_panel( 'halloween_party_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'halloween-party' ),
		'panel' => 'halloween_party_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'halloween_party_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'halloween-party' ),
		'panel' => 'halloween_party_blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('halloween_party_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
    ));
    $wp_customize->add_control(new Halloween_Party_Image_Radio_Control($wp_customize, 'halloween_party_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Post Layouts','halloween-party'),
        'section' => 'halloween_party_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('halloween_party_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'halloween_party_Customize_partial_halloween_party_toggle_postdate', 
	));

	$wp_customize->add_setting( 'halloween_party_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','halloween-party' ),
        'section' => 'halloween_party_post_settings'
    )));

    $wp_customize->add_setting( 'halloween_party_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_toggle_author',array(
		'label' => esc_html__( 'Author','halloween-party' ),
		'section' => 'halloween_party_post_settings'
    )));

    $wp_customize->add_setting( 'halloween_party_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_toggle_comments',array(
		'label' => esc_html__( 'Comments','halloween-party' ),
		'section' => 'halloween_party_post_settings'
    )));

    $wp_customize->add_setting( 'halloween_party_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_toggle_time',array(
		'label' => esc_html__( 'Time','halloween-party' ),
		'section' => 'halloween_party_post_settings'
    )));

    $wp_customize->add_setting( 'halloween_party_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
	));
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','halloween-party' ),
		'section' => 'halloween_party_post_settings'
    )));

    $wp_customize->add_setting( 'halloween_party_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
	));
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_toggle_tags', array(
		'label' => esc_html__( 'Tags','halloween-party' ),
		'section' => 'halloween_party_post_settings'
    )));

    $wp_customize->add_setting( 'halloween_party_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'halloween_party_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'halloween_party_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','halloween-party' ),
		'section'     => 'halloween_party_post_settings',
		'type'        => 'range',
		'settings'    => 'halloween_party_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('halloween_party_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','halloween-party'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','halloween-party'),
		'section'=> 'halloween_party_post_settings',
		'type'=> 'text'
	));

  $wp_customize->add_setting('halloween_party_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','halloween-party'),
        'section' => 'halloween_party_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','halloween-party'),
            'Excerpt' => esc_html__('Excerpt','halloween-party'),
            'No Content' => esc_html__('No Content','halloween-party')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'halloween_party_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'halloween-party' ),
		'panel' => 'halloween_party_blog_post_parent_panel',
	));

	$wp_customize->add_setting('halloween_party_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_button_padding_top_bottom',array(
		'label'	=> esc_html__('Padding Top Bottom','halloween-party'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'halloween-party' ),
        ),
		'section' => 'halloween_party_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('halloween_party_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_button_padding_left_right',array(
		'label'	=> esc_html__('Padding Left Right','halloween-party'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'halloween-party' ),
        ),
		'section' => 'halloween_party_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting( 'halloween_party_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'halloween_party_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'halloween_party_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','halloween-party' ),
		'section'     => 'halloween_party_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// font size button
	$wp_customize->add_setting('halloween_party_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_button_font_size',array(
		'label'	=> __('Button Font Size','halloween-party'),
		'description'	=> __('Enter a value in pixels. Example:20px','halloween-party'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'halloween-party' ),
    ),
    'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'halloween_party_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('halloween_party_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','halloween-party'),
		'choices' => array(
            'Uppercase' => __('Uppercase','halloween-party'),
            'Capitalize' => __('Capitalize','halloween-party'),
            'Lowercase' => __('Lowercase','halloween-party'),
        ),
		'section'=> 'halloween_party_button_settings',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('halloween_party_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'halloween_party_Customize_partial_halloween_party_button_text', 
	));

    $wp_customize->add_setting('halloween_party_button_text',array(
		'default'=> esc_html__('Read More','halloween-party'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_button_text',array(
		'label'	=> esc_html__('Add Button Text','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'halloween_party_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'halloween-party' ),
		'panel' => 'halloween_party_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('halloween_party_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'halloween_party_Customize_partial_halloween_party_related_post_title', 
	));

    $wp_customize->add_setting( 'halloween_party_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_related_post',array(
		'label' => esc_html__( 'Related Post','halloween-party' ),
		'section' => 'halloween_party_related_posts_settings'
    )));

    $wp_customize->add_setting('halloween_party_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('halloween_party_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('halloween_party_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'halloween_party_sanitize_number_absint'
	));
	$wp_customize->add_control('halloween_party_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','halloween-party'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'halloween-party' ),
        ),
		'section'=> 'halloween_party_related_posts_settings',
		'type'=> 'number'
	));

	// Single Posts Settings
	$wp_customize->add_section( 'halloween_party_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'halloween-party' ),
		'panel' => 'halloween_party_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'halloween_party_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
   $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_single_post_breadcrumb',array(
		'label' => esc_html__( 'Single Post Breadcrumb','halloween-party' ),
		'section' => 'halloween_party_single_blog_settings'
    )));

   // Single Posts Category
  $wp_customize->add_setting( 'halloween_party_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
  $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_single_post_category',array(
		'label' => esc_html__( 'Single Post Category','halloween-party' ),
		'section' => 'halloween_party_single_blog_settings'
    )));

   // Grid layout setting
	$wp_customize->add_section( 'halloween_party_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'halloween-party' ),
		'panel' => 'halloween_party_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'halloween_party_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
  $wp_customize->add_control( new halloween_party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_grid_postdate',array(
        'label' => esc_html__( 'Post Date','halloween-party' ),
        'section' => 'halloween_party_grid_layout_settings'
   )));

  $wp_customize->add_setting( 'halloween_party_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
  $wp_customize->add_control( new halloween_party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_grid_author',array(
	'label' => esc_html__( 'Author','halloween-party' ),
	'section' => 'halloween_party_grid_layout_settings'
  )));

  $wp_customize->add_setting( 'halloween_party_grid_comments',array(
	'default' => 1,
	'transport' => 'refresh',
	'sanitize_callback' => 'halloween_party_switch_sanitization'
  ) );
  $wp_customize->add_control( new halloween_party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_grid_comments',array(
	'label' => esc_html__( 'Comments','halloween-party' ),
	'section' => 'halloween_party_grid_layout_settings'
  )));

	//Others Settings
	$wp_customize->add_panel( 'halloween_party_others_panel', array(
		'title' => esc_html__( 'Others Settings', 'halloween-party' ),
		'panel' => 'halloween_party_panel_id',
		'priority' => 20,
	));

	// Layout
	$wp_customize->add_section( 'halloween_party_left_right', array(
    	'title' => esc_html__('General Settings', 'halloween-party'),
		'panel' => 'halloween_party_others_panel'
	) );

	$wp_customize->add_setting('halloween_party_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control(new Halloween_Party_Image_Radio_Control($wp_customize, 'halloween_party_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','halloween-party'),
        'description' => esc_html__('Here you can change the width layout of Website.','halloween-party'),
        'section' => 'halloween_party_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('halloween_party_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','halloween-party'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','halloween-party'),
        'section' => 'halloween_party_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','halloween-party'),
            'Right Sidebar' => esc_html__('Right Sidebar','halloween-party'),
            'One Column' => esc_html__('One Column','halloween-party'),
            'Grid Layout' => esc_html__('Grid Layout','halloween-party')
        ),
	) );

	$wp_customize->add_setting('halloween_party_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','halloween-party'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','halloween-party'),
        'section' => 'halloween_party_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','halloween-party'),
            'Right_Sidebar' => esc_html__('Right Sidebar','halloween-party'),
            'One_Column' => esc_html__('One Column','halloween-party')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'halloween_party_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'halloween_party_customize_partial_halloween_party_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'halloween_party_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
  $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','halloween-party' ),
		'section' => 'halloween_party_left_right'
    )));

  $wp_customize->add_setting('halloween_party_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'halloween_party_sanitize_choices'
	));
	$wp_customize->add_control('halloween_party_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','halloween-party'),
        'section' => 'halloween_party_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','halloween-party'),
            'Right Sidebar' => __('Right Sidebar','halloween-party'),
        ),
	) );

  // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'halloween_party_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'halloween_party_customize_partial_halloween_party_woocommerce_single_product_page_sidebar', ) );

  //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'halloween_party_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','halloween-party' ),
		'section' => 'halloween_party_left_right'
    )));

    $wp_customize->add_setting( 'halloween_party_single_page_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_single_page_breadcrumb',array(
		'label' => esc_html__( 'Single Page Breadcrumb','halloween-party' ),
		'section' => 'halloween_party_left_right'
    )));

    //Wow Animation
	$wp_customize->add_setting( 'halloween_party_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_switch_sanitization'
    ));
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_animation',array(
        'label' => esc_html__( 'Animations','halloween-party' ),
        'description' => __('Here you can disable overall site animation effect','halloween-party'),
        'section' => 'halloween_party_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'halloween_party_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'halloween_party_switch_sanitization'
    ) );
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','halloween-party' ),
        'section' => 'halloween_party_left_right'
    )));

	$wp_customize->add_setting('halloween_party_preloader_bg_color', array(
		'default'           => '#FF6600',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'halloween-party'),
		'section'  => 'halloween_party_left_right',
	)));

	$wp_customize->add_setting('halloween_party_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'halloween-party'),
		'section'  => 'halloween_party_left_right',
	)));

	//Responsive Media Settings
	$wp_customize->add_section('halloween_party_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','halloween-party'),
		'panel' => 'halloween_party_others_panel',
	));

    $wp_customize->add_setting( 'halloween_party_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'halloween_party_switch_sanitization'
    ));  
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','halloween-party' ),
      	'section' => 'halloween_party_responsive_media'
    )));

    $wp_customize->add_setting( 'halloween_party_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ));  
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','halloween-party' ),
      	'section' => 'halloween_party_responsive_media'
    )));

    $wp_customize->add_setting( 'halloween_party_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'halloween_party_switch_sanitization'
    ));  
    $wp_customize->add_control( new Halloween_Party_Toggle_Switch_Custom_Control( $wp_customize, 'halloween_party_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','halloween-party' ),
      	'section' => 'halloween_party_responsive_media'
    )));

    $wp_customize->add_setting('halloween_party_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'halloween_party_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'halloween-party'),
		'section'  => 'halloween_party_responsive_media',
	)));
}

add_action( 'customize_register', 'halloween_party_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Halloween_Party_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Halloween_Party_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Halloween_Party_Customize_Section_Pro( $manager,'halloween_party_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'Halloween Party PRO', 'halloween-party' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'halloween-party' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/halloween-party-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Halloween_Party_Customize_Section_Pro($manager,'halloween_party_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'halloween-party' ),
			'pro_text' => esc_html__( 'DOCS', 'halloween-party' ),
			'pro_url'  => esc_url('https://www.vwthemesdemo.com/docs/free-halloween-party/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'halloween-party-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'halloween-party-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Halloween_Party_Customize::get_instance();